# Contributing

The following is a set of guidelines for contributing to webviz-ert

## Ground Rules

1. We use PEP8
1. We use Black code formatting
1. We use Pylint

## Pull Request Process

1. Work on your own fork of the main repo
1. Push your commits and make a draft pull request using the pull request template; follow the
   instructions in the template.
1. Check that your pull request passes all tests.
1. When all tests have passed and you are happy with your changes, change your pull request to "ready for review"
   and ask for a code review.
1. When your code has been approved - merge your changes.
